@@ -246,7 +246,7 @@ void ListWindow::editItem()
         list = xml->loadProgram(str);
         qDebug() << "ListWindow::editItem 2";
         npw = new NewProgramWindow(this);
-        qDebug() << "ListWindow::editItem 3" << str;
+        qDebug() << "ListWindow::editItem 3";
         npw->load(str,list);
         npw->show();
         qDebug() << "ListWindow::editItem 4";
