@@ -1442,7 +1442,7 @@ QList<QString> XML::openGroup(QString group)
     return readInfo;
 }
 
-QList<QString> XML::openIngredients(QString type)
+QList<QString> XML::openIngredients()
 {
     QList<QString> readInfo;
     readInfo.clear();
@@ -1474,8 +1474,7 @@ QList<QString> XML::openIngredients(QString type)
       {
         if( e.tagName() == "ingredient" )
         {
-            if(e.attribute("type","") == type)
-                readInfo.append(e.attribute("name", ""));
+            readInfo.append(e.attribute("name", ""));
         }
       }
       n = n.nextSibling();
